## 0.2.12 (2025-05-30)

### Fix

- load metadata in materialize

## 0.2.11 (2025-05-30)

### Fix

- fixing missing table bug for duck db persister

### Refactor

- changed ile resource to folder resource and added full_path method

## 0.2.10 (2025-05-28)

### Fix

- simplifying the materialization steps and the metadata status

## 0.2.9 (2025-05-27)

### Fix

- improving structure and tests

## 0.2.8 (2025-04-15)

### Fix

- fixed bug in data persister patch function that did not patch the load_data method

## 0.2.7 (2025-04-15)

### Fix

- Allow data and meta persisters to register multiple assets at once

## 0.2.6 (2025-04-01)

### Fix

- fixing select statements for postgres

## 0.2.5 (2025-04-01)

### Fix

- fix error in downstream asset

## 0.2.4 (2025-04-01)

### Fix

- fixing coordinator creation

## 0.2.3 (2025-04-01)

### Fix

- resolve error in coordinator run

## 0.2.2 (2025-04-01)

### Fix

- improving coordinator

## 0.2.1 (2025-03-31)

### Fix

- improve structire using protocolls

## 0.2.0 (2025-03-31)

### Feat

- moved the coordination / materialization scripts into the coordinator, added coordinator metadata
